window.Gleam.initSearch([{"doc":"lenient_parse","title":"lenient_parse","content":"# lenient_parse\n\n[![Package Version](https://img.shields.io/hexpm/v/lenient_parse)](https://hex.pm/packages/lenient_parse)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lenient_parse/)\n\nA Gleam library providing lenient parsing functions for converting strings to float and integer values. This package offers more flexible parsing than the standard Gleam functions, similar to Python&#39;s built-in `float()` and `int()` functions.\n\n## Installation\n\n\n```sh\ngleam add lenient_parse\n```\n```gleam\nimport lenient_parse\nimport gleam/io\n\npub fn main() {\n  &quot;1&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(1.0)\n\n  &quot;1.001&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(1.001)\n\n  &quot;+123.321&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(123.321)\n\n  &quot;-123.321&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(-123.321)\n\n  &quot;1_000_000.0&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(1.0e6)\n\n  &quot;4e3&quot; |&gt; lenient_parse.to_float |&gt; io.debug\n  // Ok(4.0e3)\n\n  &quot;123&quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(123)\n\n  &quot;+123&quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(123)\n\n  &quot;-123&quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(-123)\n\n  &quot;1_000_000&quot; |&gt; lenient_parse.to_int |&gt; io.debug\n  // Ok(1000000)\n}\n```\n\n## Developer Setup\n\nTo run the tests for this package, you&#39;ll need to [install `uv`](https://docs.astral.sh/uv/getting-started/installation/).\n","url":"index.html"},{"doc":"parse_error","title":"ParseError","content":"pub type ParseError {\n  EmptyString\n  WhitespaceOnlyString\n  InvalidUnderscorePosition(index: Int)\n  InvalidDecimalPosition(index: Int)\n  InvalidSignPosition(character: String, index: Int)\n  InvalidDigitPosition(character: String, index: Int)\n  InvalidExponentSymbolPosition(character: String, index: Int)\n  UnknownCharacter(character: String, index: Int)\n}\n\nEmptyString\n Represents an error when the input string is empty.\n\nWhitespaceOnlyString\n Represents an error when the input string contains only whitespace\n characters.\n\nInvalidUnderscorePosition(index: Int)\n Represents an error when an underscore is in an invalid position within\n the number string.\n\n - `index`: The position of the invalid underscore in the input string.\n\nInvalidDecimalPosition(index: Int)\n Represents an error when a decimal point is in an invalid position within\n the number string.\n\n - `index`: The position of the invalid decimal point in the input string.\n\nInvalidSignPosition(character: String, index: Int)\n Represents an error when a sign (+ or -) is in an invalid position within\n the number string.\n\n - `character`: The sign character that caused the error as a `String`.\n - `index`: The position of the invalid sign in the input string.\n\nInvalidDigitPosition(character: String, index: Int)\n Represents an error when a digit is in an invalid position within the\n number string.\n\n - `character`: The digit character that caused the error as a `String`.\n - `index`: The position of the invalid digit in the input string.\n\nInvalidExponentSymbolPosition(character: String, index: Int)\n Represents an error when an exponent symbol (e or E) is in an invalid\n position within the number string.\n\n - `character`: The exponent symbol that caused the error as a `String`.\n - `index`: The position of the invalid exponent symbol in the input string.\n\nUnknownCharacter(character: String, index: Int)\n Represents an error when an invalid character is encountered during\n parsing.\n\n - `character`: The invalid character as a `String`.\n - `index`: The position of the invalid character in the input string.\n\nSynonyms:\nparse_error.ParseError\nparse_error ParseError","url":"parse_error.html#ParseError"},{"doc":"parse_error","title":"parse_error","content":"","url":"parse_error.html"},{"doc":"lenient_parse","title":"to_float","content":"pub fn to_float(text: String) -&gt; Result(Float, ParseError)\n Converts a string to a float using a more lenient parsing method than gleam&#39;s `float.parse()`. It behaves similarly to Python&#39;s `float()` built-in function.\n\n ## Examples\n\n \n lenient_parse.to_float(&quot;1.001&quot;)           // -&gt; Ok(1.001)\n lenient_parse.to_float(&quot;1&quot;)               // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;1.&quot;)              // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;1.0&quot;)             // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;.1&quot;)              // -&gt; Ok(0.1)\n lenient_parse.to_float(&quot;0.1&quot;)             // -&gt; Ok(0.1)\n lenient_parse.to_float(&quot;+123.321&quot;)        // -&gt; Ok(123.321)\n lenient_parse.to_float(&quot;-123.321&quot;)        // -&gt; Ok(-123.321)\n lenient_parse.to_float(&quot; 1.0 &quot;)           // -&gt; Ok(1.0)\n lenient_parse.to_float(&quot;1_000.0&quot;)         // -&gt; Ok(1.0e3)\n lenient_parse.to_float(&quot;-1_234.567_8e-2&quot;) // -&gt; Ok(-12.345678)\n lenient_parse.to_float(&quot;&quot;)                // -&gt; Error(EmptyString)\n lenient_parse.to_float(&quot; &quot;)               // -&gt; Error(WhitespaceOnlyString)\n lenient_parse.to_float(&quot;abc&quot;)             // -&gt; Error(UnknownCharacter(&quot;a&quot;, 0))\n \nSynonyms:\nlenient_parse.to_float\nlenient_parse to_float","url":"lenient_parse.html#to_float"},{"doc":"lenient_parse","title":"to_int","content":"pub fn to_int(text: String) -&gt; Result(Int, ParseError)\n Converts a string to an integer using a more lenient parsing method than gleam&#39;s `int.parse()`.\n It behaves similarly to Python&#39;s `int()` built-in function.\n\n ## Examples\n\n \n lenient_parse.to_int(&quot;123&quot;)   // -&gt; Ok(123)\n lenient_parse.to_int(&quot;+123&quot;)  // -&gt; Ok(123)\n lenient_parse.to_int(&quot;-123&quot;)  // -&gt; Ok(-123)\n lenient_parse.to_int(&quot;0123&quot;)  // -&gt; Ok(123)\n lenient_parse.to_int(&quot; 123 &quot;) // -&gt; Ok(123)\n lenient_parse.to_int(&quot;1_000&quot;) // -&gt; Ok(1000)\n lenient_parse.to_int(&quot;&quot;)      // -&gt; Error(EmptyString)\n lenient_parse.to_int(&quot;1.0&quot;)   // -&gt; Error(UnknownCharacter(&quot;.&quot;, 1))\n lenient_parse.to_int(&quot;abc&quot;)   // -&gt; Error(UnknownCharacter(&quot;a&quot;, 0))\n lenient_parse.to_int(&quot;1E4&quot;)   // -&gt; Error(UnknownCharacter(&quot;E&quot;, 1))\n \nSynonyms:\nlenient_parse.to_int\nlenient_parse to_int","url":"lenient_parse.html#to_int"},{"doc":"lenient_parse","title":"lenient_parse","content":"","url":"lenient_parse.html"}]);